@@ -38,9 +38,10 @@ int main(int argc, char *argv[])
 {
     KLocalizedString::setApplicationDomain("gwenview");
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
-    QScopedPointer<KAboutData> aboutData(Gwenview::createAboutData(QStringLiteral("org.kde.gwenview"), /* component name */
+#endif
+    QScopedPointer<KAboutData> aboutData(Gwenview::createAboutData(QStringLiteral("gwenview_importer"), /* component name */
                                                                    i18n("Gwenview Importer") /* programName */
                                                                    ));
     aboutData->setShortDescription(i18n("Photo Importer"));
@@ -63,15 +64,15 @@ int main(int argc, char *argv[])
         qCWarning(GWENVIEW_IMPORTER_LOG) << i18n("Too many arguments.");
         parser.showHelp();
     }
-    QString urlString = parser.positionalArguments().constFirst();
-    QUrl url = QUrl::fromUserInput(urlString, QDir::currentPath(), QUrl::AssumeLocalFile);
+    const QString urlString = parser.positionalArguments().constFirst();
+    const QUrl url = QUrl::fromUserInput(urlString, QDir::currentPath(), QUrl::AssumeLocalFile);
     if (!url.isValid()) {
         qCCritical(GWENVIEW_IMPORTER_LOG) << i18n("Invalid source folder.");
         return 1;
     }
-    QString deviceUdi = parser.isSet(QStringLiteral("udi")) ? parser.value(QStringLiteral("udi")) : QString();
+    const QString deviceUdi = parser.isSet(QStringLiteral("udi")) ? parser.value(QStringLiteral("udi")) : QString();
 
-    auto *dialog = new Gwenview::ImportDialog();
+    auto dialog = new Gwenview::ImportDialog();
     dialog->show();
     QMetaObject::invokeMethod(
         dialog,
