@@ -27,7 +27,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QImageReader>
 #include <QMimeData>
 #include <QMimeDatabase>
-#include <QStringList>
 #include <QUrl>
 
 // KF
@@ -176,7 +175,7 @@ Kind urlKind(const QUrl &url)
 
 QMimeData *selectionMimeData(const KFileItemList &selectedFiles, MimeTarget mimeTarget)
 {
-    auto *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
 
     if (selectedFiles.count() == 1) {
         // When a single file is selected, there are a couple of cases:
